==> jc-1.4.0.tar.gz: polyglot/visit/DumpAst.h <==
// public class polyglot.visit.DumpAst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ef9e4eb99a337545 polyglot_visit_DumpAst
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_DumpAst_H_
#define _JC_polyglot_visit_DumpAst_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_DumpAst$sub_refs	_jc_polyglot_visit_DumpAst$sub_refs;
typedef struct _jc_polyglot_visit_DumpAst$sub_nonrefs	_jc_polyglot_visit_DumpAst$sub_nonrefs;
typedef struct _jc_polyglot_visit_DumpAst$refs	_jc_polyglot_visit_DumpAst$refs;
typedef struct _jc_polyglot_visit_DumpAst$nonrefs	_jc_polyglot_visit_DumpAst$nonrefs;
typedef struct _jc_polyglot_visit_DumpAst$object	_jc_polyglot_visit_DumpAst$object;

typedef const struct _jc_polyglot_visit_DumpAst$vmethods	_jc_polyglot_visit_DumpAst$vmethods;
typedef const struct _jc_polyglot_visit_DumpAst$vtable	_jc_polyglot_visit_DumpAst$vtable;
typedef const struct _jc_polyglot_visit_DumpAst$vtype	_jc_polyglot_visit_DumpAst$vtype;

// Constructors
extern void _jc_polyglot_visit_DumpAst$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *, struct _jc_java_lang_String$object *, jint);
extern void _jc_polyglot_visit_DumpAst$method$_init$3f6fe8a81021d7b4(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *, struct _jc_polyglot_util_CodeWriter$object *);

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_DumpAst$method$enter$a8ce2b9db363b202(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *, struct _jc_object *);
extern void _jc_polyglot_visit_DumpAst$method$finish$8d1c944274527186(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *);
extern struct _jc_object *_jc_polyglot_visit_DumpAst$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_DumpAst$method_info$enter$a8ce2b9db363b202;
extern _jc_method _jc_polyglot_visit_DumpAst$method_info$finish$8d1c944274527186;
extern _jc_method _jc_polyglot_visit_DumpAst$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_polyglot_visit_DumpAst$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$a8ce2b9db363b202)(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *, struct _jc_object *);
	void	(*finish$8d1c944274527186)(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *);
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_polyglot_visit_DumpAst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_DumpAst$vmethods	polyglot_visit_DumpAst;
};

// Vtype
struct _jc_polyglot_visit_DumpAst$vtype {
	_jc_type			type;
	_jc_polyglot_visit_DumpAst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_DumpAst$sub_refs {
	struct _jc_java_io_Writer$object	*fw;
	struct _jc_polyglot_util_CodeWriter$object	*w;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_DumpAst$refs {
    _jc_polyglot_visit_DumpAst$sub_refs	polyglot_visit_DumpAst;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_DumpAst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_DumpAst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_DumpAst$sub_nonrefs	polyglot_visit_DumpAst;
};

// Object instance structure
struct _jc_polyglot_visit_DumpAst$object {
	_jc_polyglot_visit_DumpAst$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_DumpAst$vtype	*vtype;
	_jc_polyglot_visit_DumpAst$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_DumpAst$vtype _jc_polyglot_visit_DumpAst$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_DumpAst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_DumpAst$class_object;

#endif	/* _JC_polyglot_visit_DumpAst_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/DumpAst.h <==
// public class polyglot.visit.DumpAst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ef9e4eb99a337545 polyglot_visit_DumpAst
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_DumpAst_H_
#define _JC_polyglot_visit_DumpAst_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_DumpAst$sub_refs	_jc_polyglot_visit_DumpAst$sub_refs;
typedef struct _jc_polyglot_visit_DumpAst$sub_nonrefs	_jc_polyglot_visit_DumpAst$sub_nonrefs;
typedef struct _jc_polyglot_visit_DumpAst$refs	_jc_polyglot_visit_DumpAst$refs;
typedef struct _jc_polyglot_visit_DumpAst$nonrefs	_jc_polyglot_visit_DumpAst$nonrefs;
typedef struct _jc_polyglot_visit_DumpAst$object	_jc_polyglot_visit_DumpAst$object;

typedef const struct _jc_polyglot_visit_DumpAst$vmethods	_jc_polyglot_visit_DumpAst$vmethods;
typedef const struct _jc_polyglot_visit_DumpAst$vtable	_jc_polyglot_visit_DumpAst$vtable;
typedef const struct _jc_polyglot_visit_DumpAst$vtype	_jc_polyglot_visit_DumpAst$vtype;

// Constructors
extern void _jc_polyglot_visit_DumpAst$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern void _jc_polyglot_visit_DumpAst$method$_init$3f6fe8a81021d7b4(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *, struct _jc_polyglot_util_CodeWriter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_DumpAst$method$enter$a8ce2b9db363b202(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_visit_DumpAst$method$finish$8d1c944274527186(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_DumpAst$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_DumpAst$method_info$enter$a8ce2b9db363b202;
extern _jc_method _jc_polyglot_visit_DumpAst$method_info$finish$8d1c944274527186;
extern _jc_method _jc_polyglot_visit_DumpAst$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_polyglot_visit_DumpAst$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$a8ce2b9db363b202)(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*finish$8d1c944274527186)(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_DumpAst$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_DumpAst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_DumpAst$vmethods	polyglot_visit_DumpAst;
};

// Vtype
struct _jc_polyglot_visit_DumpAst$vtype {
	_jc_type			type;
	_jc_polyglot_visit_DumpAst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_DumpAst$sub_refs {
	struct _jc_java_io_Writer$object	*fw;
	struct _jc_polyglot_util_CodeWriter$object	*w;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_DumpAst$refs {
    _jc_polyglot_visit_DumpAst$sub_refs	polyglot_visit_DumpAst;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_DumpAst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_DumpAst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_DumpAst$sub_nonrefs	polyglot_visit_DumpAst;
};

// Object instance structure
struct _jc_polyglot_visit_DumpAst$object {
	_jc_polyglot_visit_DumpAst$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_DumpAst$vtype	*vtype;
	_jc_polyglot_visit_DumpAst$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_DumpAst$vtype _jc_polyglot_visit_DumpAst$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_DumpAst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_DumpAst$class_object;

#endif	/* _JC_polyglot_visit_DumpAst_H_ */
